@@ -199,18 +199,29 @@ current user.
 
 To initialize the database or reset it to a pristine state:
 
-    # dochazka-dbinit
-    Dochazka database reset to pristine state
+    $ dochazka-resetdb
+
+Note that this is a two-step process. The first step is to create the database,
+role, extensions etc. - i.e., everything that requires database superuser
+permissions. The second step is to create the schemas, etc. For this, the
+ordinary "dochazka" role is used.
+
+In a production setting, or whenever the two steps need to be done separately,
+the database administrator can perform the first step using the "psql" command
+in C<bin/dochazka-resetdb>. After that, the second step can be performed by
+simply running
+
+    $ dochazka-dbinit
 
 
 =head2 Start the server
 
 The last step is to start the Dochazka REST server. In the future, this
-will be possible using a command like C<systemctl start dochazka.service>.
+will be possible using a command like C<systemctl start dochazka-rest.service>.
 At the moment, however, we are still in development/testing phase and we 
 start the server like this:
 
-    # dochazka-rest
+    $ dochazka-rest
     Starting Web::MREST ver. 0.282
     App distro is App-Dochazka-REST
     App module is App::Dochazka::REST::Dispatch
@@ -224,6 +235,11 @@ start the server like this:
     Starting server
     HTTP::Server::PSGI: Accepting connections at http://0:5000/
 
+Note that the development web server L<HTTP::Server::PSGI> is used. To use
+L<Starman> instead, use the following command:
+
+    $ dochazka-rest -- --server Starman
+
 
 =head2 Take it for a spin
 
